@@ -1,15 +1,15 @@
 
  ##=================================************************************************=================================##
  ## This file contains functions that are used for summarizing the MCMC data generated to make inference on pleiotropy.
- ## These functions are also the same for both uncorrelated and correlated versions of CPBayes. 
+ ## These functions are also the same for both uncorrelated and correlated versions of CPBayes.
  ## There is also one function which can be used for making some post summaries for interesting variants
  ## For example, estimating the direction of associations and posterior mean/median of beta or odds ratios
- ##=================================************************************************=================================## 
+ ##=================================************************************************=================================##
 
  ##======================********** subset selection using the MCMC sample data ***********==========================##
 
  select_subset <- function( K, Z.data, mcmc.samplesize )
- {  
+ {
      #asso.pr = colSums(Z.data)/mcmc.samplesize
      z = as.data.frame(Z.data)
      Z.summary = aggregate(z, by=z, length)[1:(ncol(z)+1)]
@@ -74,26 +74,26 @@
  }
 
  ##===========================********** post summaries for a pleiotropy signal ***********==========================##
- ## (1-level)% credible interval to be computed by CPBayes 
- ## default value of level = 0.05. It also computes posterior summary of beta and odds ratio  
- ##===========================*************************************************************==========================## 
-## Post processing of the mcmc data genarated by MCMC. 
+ ## (1-level)% credible interval to be computed by CPBayes
+ ## default value of level = 0.05. It also computes posterior summary of beta and odds ratio
+ ##===========================*************************************************************==========================##
+## Post processing of the mcmc data genarated by MCMC.
 #' Post summary of the MCMC data generated by the uncorrelated or correlated version of CPBayes.
-#' 
+#'
 #' Run the \code{\link{post_summaries}} function to summarize the MCMC data produced by
 #'  \code{\link{cpbayes_uncor}} or \code{\link{cpbayes_cor}} and obtain meaningful insights
 #'   into an observed pleiotropic signal.
-#'      
-#' @param mcmc_output A list returned by either 
-#'  \code{\link{cpbayes_uncor}} or \code{\link{cpbayes_cor}}. This list 
+#'
+#' @param mcmc_output A list returned by either
+#'  \code{\link{cpbayes_uncor}} or \code{\link{cpbayes_cor}}. This list
 #' contains the primary results and MCMC data produced by \code{\link{cpbayes_uncor}}
 #'  or \code{\link{cpbayes_cor}}. No default is specified. See the example below.
 #' @param level A numeric value. (1-level)\% credible interval (Bayesian analog of the
 #'  confidence interval) of the unknown true genetic effect (beta/odds ratio)
  #'   on each trait is computed. Default choice is 0.05.
-#' @return The output produced by this function is a list that consists of various components. 
+#' @return The output produced by this function is a list that consists of various components.
 #'    \item{variantName}{It is the name of the genetic variant provided by the user. If not
-#'     specified by the user, default name is `Variant'.} 
+#'     specified by the user, default name is `Variant'.}
 #'    \item{log10_BF}{It provides the log10(Bayes factor) produced by CPBayes that measures
 #'     the evidence of the overall pleiotropic association.}
 #'    \item{locFDR}{It provides the local false discovery rate (posterior probability of null association) produced by
@@ -123,13 +123,13 @@
 #'        true beta corresponding to each trait.}
 #'     \item{poste_summary_OR}{Data frame providing the posterior summary of the unknown
 #'      true genetic effect (odds ratio) on each trait. It gives posterior mean, median,
-#'       standard error, credible interval (lower and upper limits) of the true odds 
+#'       standard error, credible interval (lower and upper limits) of the true odds
 #'        ratio corresponding to each trait.}
-#'        
+#'
 #' @references Majumdar A, Haldar T, Bhattacharya S, Witte JS (2018) An efficient Bayesian meta analysis approach for studying cross-phenotype genetic associations. PLoS Genet 14(2): e1007139.
-#'  
-#' @seealso \code{\link{cpbayes_uncor}}, \code{\link{cpbayes_cor}}, \code{\link{forest_cpbayes}}, \code{\link{estimate_corln}}
-#' 
+#'
+#' @seealso \code{\link{cpbayes_uncor}}, \code{\link{cpbayes_cor}}
+#'
 #' @examples
 #' data(ExampleDataUncor)
 #' BetaHat <- ExampleDataUncor$BetaHat
@@ -139,9 +139,9 @@
 #' traitNames <- paste("Disease", 1:10, sep = "")
 #' SNP1 <- "rs1234"
 #' result <- cpbayes_uncor(BetaHat, SE, Phenotypes = traitNames, Variant = SNP1)
-#' PleioSumm <- post_summaries(result, level = 0.05) 
+#' PleioSumm <- post_summaries(result, level = 0.05)
 #' str(PleioSumm)
-#' 
+#'
 #' @export
  post_summaries <- function( mcmc_output, level = 0.05 )
  {
@@ -151,23 +151,23 @@
      PPNA <- mcmc_output$locFDR
      subset <- mcmc_output$subset
      important_phenos <- mcmc_output$important_traits
-   
+
   	 MCMC_data <- mcmc_output$auxi_data
- 	
-  	 traitNames <- MCMC_data$traitNames 	      
+
+  	 traitNames <- MCMC_data$traitNames
      K <- MCMC_data$K
      mcmc.samplesize <- MCMC_data$mcmc.samplesize
      asso.pr <- MCMC_data$PPAj
-     Z.data <- MCMC_data$Z.data 
-     sim.beta <- MCMC_data$sim.beta 
-     
+     Z.data <- MCMC_data$Z.data
+     sim.beta <- MCMC_data$sim.beta
+
      asso_prob = data.frame( traits = traitNames, PPAj = asso.pr, stringsAsFactors = FALSE)
-    
+
      ## estimate the direction of associations
      alldirection <- estimate_directions( K, sim.beta )
-     
+
      optimal_subset <- data.frame( traits = subset, stringsAsFactors = FALSE)
-     
+
      if( length(subset) > 0 ){
          selected <- match(subset, traitNames)
          optimal_subset$PPAj <- asso.pr[selected]
@@ -180,8 +180,8 @@
          direct <- alldirection[selected]
          important_phenos$direction = direct
      }
-     
-     ## for summarizing the 'beta' parameters themselves 
+
+     ## for summarizing the 'beta' parameters themselves
      poste_mean_beta <- 0
      poste_median_beta <- 0
      poste_se_beta <- 0
@@ -212,42 +212,41 @@
           poste_median_OR[k] <- or_qtls[2]
           CI_OR_u[k] <- or_qtls[3]
      }
-     
-     poste_summary_beta = data.frame( traits = traitNames, poste_mean = poste_mean_beta, 
-                          poste_median = poste_median_beta, poste_se = poste_se_beta, lCl = CI_l, 
+
+     poste_summary_beta = data.frame( traits = traitNames, poste_mean = poste_mean_beta,
+                          poste_median = poste_median_beta, poste_se = poste_se_beta, lCl = CI_l,
                           uCl = CI_u, stringsAsFactors = FALSE)
-     
-     poste_summary_OR = data.frame( traits = traitNames, poste_mean = poste_mean_OR, poste_median = poste_median_OR, 
+
+     poste_summary_OR = data.frame( traits = traitNames, poste_mean = poste_mean_OR, poste_median = poste_median_OR,
                         lCl = CI_OR_l, uCl = CI_OR_u, stringsAsFactors = FALSE)
-    
-     data = list( variantName = genetic_variant, log10_BF = log10_BF, locFDR = PPNA, subset = optimal_subset, 
-            important_traits = important_phenos, traitNames = traitNames, PPAj = asso_prob, 
+
+     data = list( variantName = genetic_variant, log10_BF = log10_BF, locFDR = PPNA, subset = optimal_subset,
+            important_traits = important_phenos, traitNames = traitNames, PPAj = asso_prob,
             poste_summary_beta = poste_summary_beta, poste_summary_OR = poste_summary_OR )
  }
 
- 
+
 ##===========================********** Forest plot for a pleiotropy signal ***********==========================##
 ## (1-level)% confidence interval of beta parameter is to be plotted in the forest plot. default value of level = 0.05.
-##===========================*************************************************************==========================## 
+##===========================*************************************************************==========================##
 ## Forest plot presenting pleiotropy result obtained by CPBayes.
 #' Forest plot presenting pleiotropy result obtained by CPBayes.
-#' 
+#'
 #' Run the \code{\link{forest_cpbayes}} function to create a forest plot that presents the pleiotropy result obtained
 #' by \code{\link{cpbayes_uncor}} or \code{\link{cpbayes_cor}}.
-#'      
-#' @param mcmc_output A list returned by either 
-#'  \code{\link{cpbayes_uncor}} or \code{\link{cpbayes_cor}}. This list 
+#'
+#' @param mcmc_output A list returned by either
+#'  \code{\link{cpbayes_uncor}} or \code{\link{cpbayes_cor}}. This list
 #' contains all the primary results and MCMC data produced by \code{\link{cpbayes_uncor}}
 #'  or \code{\link{cpbayes_cor}}. No default is specified. See the example below.
 #' @param level A numeric value. (1-level)\% confidence interval of the unknown true genetic effect (beta/log(odds ratio))
 #'   on each trait is plotted in the forest plot. Default choice is 0.05.
 #' @param PPAj_cutoff A numeric value. It's a user-specified threshold of PPAj (trait-specific posterior probability
-#'   of association). Only those traits having PPAj values above this cut-off are included in the forest plot. So, the choice of 
+#'   of association). Only those traits having PPAj values above this cut-off are included in the forest plot. So, the choice of
 #'   this variable as '0.0' includes all traits in the forest plot. Default is 0.01.
-#' @return The output produced by this function is a diagram file in .pdf format. The details of the diagram are as follows: 
+#' @return The output produced by this function is a diagram file in .pdf format. The details of the diagram are as follows:
 #'    \item{file_name}{The pdf file is named after the genetic variant. So, if the argument `Variant'
-#'    in \code{\link{cpbayes_uncor}} or \code{\link{cpbayes_cor}} is specified as 'rs1234', the figure file is named as rs1234.pdf.} 
-#'    \item{Title}{At the top of the figure, variant name and the corresponding locFDR and log10(Bayes factor) produced by CPBayes is stated.}
+#'    in \code{\link{cpbayes_uncor}} or \code{\link{cpbayes_cor}} is specified as 'rs1234', the figure file is named as rs1234.pdf.}
 #'    \item{Column1}{First column in the figure specifies the name of the phenotypes.}
 #'    \item{Column2}{Second column provides the trait-specific univariate association p-value for a trait.}
 #'    \item{Column3}{Third column provides the trait-specific posterior probability of association (PPAj) produced by CPBayes.}
@@ -257,9 +256,9 @@
 #'    \item{Column5}{In the right section of the figure, the primary eatimate and confidence interval of the beta/log odds ratio parameter for
 #'     a trait is plotted.}
 #' @references Majumdar A, Haldar T, Bhattacharya S, Witte JS (2018) An efficient Bayesian meta analysis approach for studying cross-phenotype genetic associations. PLoS Genet 14(2): e1007139.
-#'  
-#' @seealso \code{\link{cpbayes_uncor}}, \code{\link{cpbayes_cor}}, \code{\link{post_summaries}}, \code{\link{estimate_corln}}
-#' 
+#'
+#' @seealso \code{\link{cpbayes_uncor}}, \code{\link{cpbayes_cor}}
+#'
 #' @examples
 #' data(ExampleDataUncor)
 #' BetaHat <- ExampleDataUncor$BetaHat
@@ -267,8 +266,8 @@
 #' traitNames <- paste("Disease", 1:10, sep = "")
 #' SNP1 <- "rs1234"
 #' result <- cpbayes_uncor(BetaHat, SE, Phenotypes = traitNames, Variant = SNP1)
-#' forest_cpbayes(result, level = 0.05) 
-#' 
+#' forest_cpbayes(result, level = 0.05)
+#'
 #' @export
 forest_cpbayes <- function(mcmc_output, level = 0.05, PPAj_cutoff = 0.01){
 
@@ -290,14 +289,14 @@ forest_cpbayes <- function(mcmc_output, level = 0.05, PPAj_cutoff = 0.01){
    upper_alfa <- abs(qnorm( (level/2), 0,1))
    shift <- upper_alfa*se
    lowCIbeta <- betahat - shift                            ## lower confidence interval of beta
-   upCIbeta <- betahat + shift                             ## upper confidence interval of 
+   upCIbeta <- betahat + shift                             ## upper confidence interval of
    pvalues <- pchisq( (betahat/se)^2, df=1, lower.tail=F )
 
    for(j in 1:K){
      x <- pvalues[j]
      count <- 0
      while(x < 1){ x <- 10*x; count <- count+1 }
-     pvalues[j] <- round(pvalues[j], digits = count)     ## or, digits = count 
+     pvalues[j] <- round(pvalues[j], digits = count)     ## or, digits = count
    }
 
    PPAj <- summ$PPAj$PPAj
@@ -322,15 +321,13 @@ forest_cpbayes <- function(mcmc_output, level = 0.05, PPAj_cutoff = 0.01){
    while(x < 1){ x <- 10*x; count <- count+1 }
    PPNA <- round(PPNA, digits = count+1)
 
-
-
    if(length(select) > 0){
 
      select <- select+1
      select <- c(1,select)
      title <- summ$variantName
      pdffile <- paste(title, ".pdf", sep = "")
-     title <- paste("Pleiotropy at ", title, ": locFDR = ", PPNA, ", log10BF = ", log10BF, sep = "")   ##  "PPNA = ", PPNA,
+     title <- paste("Pleiotropy at ", title, sep = "")   ##  "PPNA = ", PPNA,
      pdf(pdffile)
 
      forestplot(labeltext[select, ], betahat[select], lowCIbeta[select], upCIbeta[select],
@@ -344,4 +341,4 @@ forest_cpbayes <- function(mcmc_output, level = 0.05, PPAj_cutoff = 0.01){
 
 }
 
- 
+
